#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                   libyaml
version:                0.1.4
visibility:             public
id:                     libyaml-0.1.4-Db9N7L69rTK81VXM280YfT
key:                    libyaml-0.1.4-Db9N7L69rTK81VXM280YfT
license:                BSD-3-Clause
maintainer:             Michael Snoyman <michael@snoyman.com>
author:
    Michael Snoyman <michael@snoyman.com>, Anton Ageev <antage@gmail.com>,Kirill Simonov

stability:              stable
homepage:               https://github.com/snoyberg/yaml#readme
synopsis:               Low-level, streaming YAML interface.
description:
    README and API documentation are available at <https://www.stackage.org/package/libyaml>

category:               Text
abi:                    c3ffdc9abb7b2411ed6458702624672e
exposed:                True
exposed-modules:        Text.Libyaml
hidden-modules:         Paths_libyaml
import-dirs:            /usr/lib/ghc-9.6.6/site-local/libyaml-0.1.4
library-dirs:           /usr/lib/ghc-9.6.6/site-local/libyaml-0.1.4 /usr/lib
library-dirs-static:    /usr/lib/ghc-9.6.6/site-local/libyaml-0.1.4 /usr/lib
dynamic-library-dirs:   /usr/lib /usr/lib
data-dir:               /usr/share/haskell-libyaml
hs-libraries:           HSlibyaml-0.1.4-Db9N7L69rTK81VXM280YfT
extra-libraries:        yaml
extra-libraries-static: yaml
include-dirs:           /usr/include
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    conduit-1.3.6.1-FIwCK0b1Hr15S6D1xh1znT
    resourcet-1.3.0-Cuj4zJihfYr1ci2ntaM4ld

haddock-interfaces:     /usr/share/doc/haskell-libyaml/html/libyaml.haddock
haddock-html:           /usr/share/doc/haskell-libyaml/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

